<template>
  <LoadingLayout>
    <AppContainer>
      <PageFormLayout title="申报详情">
        <DetailView :form="form">
          <ChunkCellV2 title="申报企业名单">
            <DeclareEnterpriseTableView
              :getList="getList"
              :extra-param-state="extraParamState"
              :pro-table-props="proTableProps"
              :reset="reset"
              :column="addRewardApplyStep3Columns"
              :operationBtns="operationBtns"
            ></DeclareEnterpriseTableView>
            <MateriaDetailDialog
              v-bind="dialogProps"
              :show-upload-btn="false"
              :show-delete-btn="false"
              :show-check-btn="false"
            />
          </ChunkCellV2>
        </DetailView>
        <template #footer>
          <el-button @click="handleBack" type="primary">确认</el-button>
        </template>
      </PageFormLayout>
    </AppContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import { AppContainer, LoadingLayout, PageFormLayout } from '@bole-core/components';
import DetailView from '@/components/commonView/DetailView.vue';
import ChunkCellV2 from '@/components/Layout/ChunkCellV2.vue';
import MateriaDetailDialog from '@/components/commonView/MateriaDetailDialog.vue';
import DeclareEnterpriseTableView from '@/components/commonView/DeclareEnterpriseTableView.vue';
import { useQuery } from '@tanstack/vue-query';
import * as parkBountyApplyServices from '@/services/api/ParkBountyApply';
import { useDeclareEnterpriseTable, useRouteView } from '@/hooks';
import { useAddRewardApplyStep3Columns } from '@/constants';
import { useIndustrialParkDropDownList } from '@/hooks/industrialPark';
import {
  CustomerApplyFileTypeListItem,
  EnterpriseApplyFileUtils,
} from '@/components/commonView/utils';

defineOptions({
  name: 'RewardDeclareDetail',
});

const route = useRoute();
const { closeViewPush } = useRouteView();
const id = route.params?.id as string;
const form = reactive({
  batchNo: '',
  parkName: '',
  parkTypeName: '',
  applyMonth: '',
  applySumAmount: 0,
  financeSumAmount: 0,
  settleSumAmount: 0,
  parkCollectFileList: [] as CustomerApplyFileTypeListItem[],
  calculationFileList: [] as CustomerApplyFileTypeListItem[],
  suportPlatRecharge: false,
});

const { addRewardApplyStep3Columns } = useAddRewardApplyStep3Columns({
  suportPlatRecharge: toRef(form, 'suportPlatRecharge'),
});

const { extraParamState, getList, reset, proTableProps, operationBtns, dialogProps } =
  useDeclareEnterpriseTable({
    id: ref(id),
    applyMonth: toRef(form, 'applyMonth'),
  });

const { data: detail, isLoading } = useQuery({
  queryKey: ['parkBountyApplyServices/getParkBountyApplyDetailBaseInfo', id],
  queryFn: async () => {
    return await parkBountyApplyServices.getParkBountyApplyDetailBaseInfo(
      { parkBountyApplyId: id },
      {
        showLoading: false,
      }
    );
  },
  placeholderData: () => ({} as API.ParkBountyApplyBaseInfo),
  onSuccess(data) {
    form.batchNo = data.batchNo;
    form.parkName = data.parkName;
    form.parkTypeName = data.parkTypeName;
    form.applyMonth = data.applyMonth;
    form.applySumAmount = data.applySumAmount;
    form.financeSumAmount = data.financeSumAmount;
    form.settleSumAmount = data.settleSumAmount;
    form.parkCollectFileList = EnterpriseApplyFileUtils.convertApiFileToParkCollectFileList(
      data.listFiles
    );
    form.calculationFileList = EnterpriseApplyFileUtils.convertApiFileToParkCollectFileList(
      data.collectCountListFiles
    );
    form.suportPlatRecharge = data.suportPlatRecharge;

    getList();
  },
});

function handleBack() {
  closeViewPush(route, {
    name: 'RewardGrant',
  });
}
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
